@@ -21,7 +21,7 @@ import sys
 
 if sys.version_info[0] == 3:
     iterkeys = lambda x: x.keys()
-    iteritems = lambda x: x.items()
+    iteritems = lambda x: iter(x.items())
     isstring = lambda x: isinstance(x, str)
     from urllib.parse import urlparse
     xrange = range
@@ -1518,4 +1518,4 @@ class Parser(object):
 
 
 __all__ = ['Parser']
-__version__ = '0.2.23b'
+__version__ = '0.2.24b'
